/*
    This file is part of the Okteta Kasten module, made within the KDE community.

    SPDX-FileCopyrightText: 2013 Friedrich W. H. Kossebau <kossebau@kde.org>

    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
*/

#ifndef KASTEN_OKTETAKASTENGUI_HPP
#define KASTEN_OKTETAKASTENGUI_HPP

// Qt
#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(LOG_KASTEN_OKTETA_GUI)

#endif
